from setuptools import setup, find_packages

setup(
    name="llmmerge",
    version="0.2.0",
    packages=find_packages(),
    install_requires=[],  # Add dependencies here if needed
    entry_points={
        "console_scripts": [
            "llmmerge-driver = llmmerge.driver:main"
        ]
    },
    author="Abhishek Agarwal",
    email="ultimateabhi@gmail.com",
    description="A custom LLM-based git merge driver.",
    python_requires=">=3.10",
)



import sys
from llmmerge.core import llm_merge

def main():
    if len(sys.argv) != 5:
        print("Usage: llmmerge-driver <base> <ours> <theirs> <output>")
        sys.exit(2)
    base, ours, theirs, output = sys.argv[1:5]
    merged_file_string = llm_merge(base, ours, theirs)
    if merged_file_string:
        with open(output, "w") as f_out:
            f_out.write(merged_file_string)
        sys.exit(0)
    else:
        sys.exit(1)

if __name__ == "__main__":
    main()
